@@ -34,6 +34,7 @@ setRefClass("ErrorLocalizer",
 #' the data.
 #' @include MipRules.R
 #' @exportClass FHLocalizer
+#' @import parallel
 #'
 fh_localizer <-
   setRefClass("FHLocalizer",
@@ -82,7 +83,7 @@ fh_localizer <-
 
         # checking size of numeric columns
         too_big <- sapply(data[numvars], function(v){
-          any(abs(v) > 1e7)
+          any(abs(v) > 1e7, na.rm = TRUE)
         })
 
         if (isTRUE(any(too_big))){
